@@ -83,10 +83,6 @@ def main_replay(arguments: list[str]) -> int:
     ap.add_argument("-v", "--version", action="version", version=get_version_string())
     args = ap.parse_args(arguments)
 
-    if args.version:
-        print(__package__, "version", version(__package__))
-        return 0
-
 
     # Allow specifying the basename (like ~/.shell-command-logs/echo/2022w11g_133650_63ff),
     # or either file (the *.log or the *.time). If a file with the extention is given, the extension is removed
